@@ -85,10 +85,17 @@
 # define STRICT_ALIGN !(defined(__i386) || defined (__amd64))
 #endif
 
+/*
+ * Use string functions to copy memory.
+ * this is usually a loss, even with glibc's optimized memcpy
+ */
+#ifndef USE_MEMCPY
+# define USE_MEMCPY 0
+#endif
+
 /*
  * You may choose to pre-set the hash table (might be faster on some
- * modern cpus and large (>>64k) blocks, and also makes compression
- * deterministic/repeatable when the configuration otherwise is the same).
+ * modern cpus and large (>>64k) blocks)
  */
 #ifndef INIT_HTAB
 # define INIT_HTAB 0
@@ -150,7 +157,7 @@ typedef const u8 *LZF_STATE[1 << (HLOG)];
 # endif
 #endif
 
-#if INIT_HTAB
+#if USE_MEMCPY || INIT_HTAB
 # ifdef __cplusplus
 #  include <cstring>
 # else
